
clear all
close all
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% plot x_{n+1} over x_n
r = 0.7484;
x = linspace(0,1,200);
x_n1 = 4*r*x .* (1 - x);

x_fp_1 = 0;
x_fp_2 = 1 - 1/(4*r);

x_n1_fp_1 = 4*r*x_fp_1 .* (1 - x_fp_1);
x_n1_fp_2 = 4*r*x_fp_2 .* (1 - x_fp_2);

figure, hold on, grid on 
plot(x,x_n1,'.')
plot(x,x,'r--')
plot([x_fp_1 x_fp_2], [x_n1_fp_1 x_n1_fp_2], 'or', 'MarkerSize', 10)
xlabel('x_n')
ylabel('x_{n+1}')
legend('Logistic map', 'x_{n+1}=x_n', 'Fixed points')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Phase space
x0 = 0.1;
N = 200;

r = .1;  %4, fp2 stable
r = 0.5; %1, fp1 stable
r = 0.65; %2, fp1 stable
r = 0.7484; %3, fp1 (still) stable
r = .9;  %5, chaos

fp_1 = 1 - 1/(4*r)
y = logistic(N,r,x0); 

figure
plot(y(:,1), 'b.-'), grid on
xlabel('n')
ylabel('y[n]')

%plot trajectory and map
figure, hold on, grid on
x = linspace(0,1,200);
x_n1 = 4*r*x .* (1 - x);
plot(x,x_n1,'.')
plot(x,x,'r--')

for i = 1:N-2
  hold on
  plot([y(i),y(i+1)], [y(i+1), y(i+2)], 'go-', 'MarkerSize', 6, 'MarkerFaceColor', 'g')
end
xlabel('x[n]')
ylabel('x[n+1]')
grid on
title('Trajectory')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Bifurcation diagram

r = [0 1];
N = 1000;
x0 = .1;

bif=logistic_bif(r,N,x0);

figure
subplot(211), hold on, grid on
plot(bif(:,1),bif(:,2),'.')
xlabel('r')
ylabel('Amplitudes')
title('Bifurcation diagram')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Lyapunov exponent
[L,r]=logistic_lyap([0 1]);

subplot(212), hold on, grid on
plot(r, L)
xlabel('r')
ylabel('\lambda')
title('Estimated Lyapunov exponent')

